@@ -1,5 +1,5 @@
 package App::HL7::Compare::Parser::Role::Partible;
-$App::HL7::Compare::Parser::Role::Partible::VERSION = '0.001';
+$App::HL7::Compare::Parser::Role::Partible::VERSION = '0.002';
 use v5.10;
 use strict;
 use warnings;
@@ -48,9 +48,9 @@ sub split_and_build
 {
 	my ($self, $string_to_split, $class_to_build) = @_;
 
-	my @parts = map { $self->_trimmed($_) } split quotemeta($self->part_separator), $string_to_split;
+	my @parts = map { $self->_trimmed($_) } split quotemeta($self->part_separator), $string_to_split, -1;
 
-	App::HL7::Compare::Exception->raise("empty value for $class_to_build")
+	App::HL7::Compare::Exception->raise("empty value for $class_to_build in: <$string_to_split>")
 		if @parts == 0;
 
 	return [
